@@ -1,7 +1,7 @@
 /**
- * jQuery Ajax Loading Overlay 0.1.1
+ * jQuery Ajax Loading Overlay 0.1.2
  *
- * Copyright (c) 2011, Jonny Gerig Meyer
+ * Copyright (c) 2012, Jonny Gerig Meyer
  * All rights reserved.
  *
  * Licensed under the New BSD License
@@ -18,16 +18,16 @@
 
     var methods = {
         init: function (opts) {
-            var options = $.extend({}, $.fn.loadingOverlay.defaults, opts),
-                target = $(this).addClass(options.loadingClass),
-                vertHeight = ((parseInt(target.css('height'), 10) - parseInt(target.css('line-height'), 10)) / 2).toString() + 'px',
-                overlay = '<span class="' + options.overlayClass + '" style="padding-top: ' + vertHeight + ';">' + options.loadingText + '</span>';
+            var options = $.extend({}, $.fn.loadingOverlay.defaults, opts);
+            var target = $(this).addClass(options.loadingClass);
+            var vertHeight = options.paddingTop(target);
+            var overlay = '<span class="' + options.overlayClass + '" style="padding-top: ' + vertHeight + ';">' + options.loadingText + '</span>';
             target.prepend(overlay);
         },
 
         remove: function (opts) {
-            var options = $.extend({}, $.fn.loadingOverlay.defaults, opts),
-                target = $(this);
+            var options = $.extend({}, $.fn.loadingOverlay.defaults, opts);
+            var target = $(this);
             target.find('.' + options.overlayClass).detach();
             if (target.hasClass(options.loadingClass)) {
                 target.removeClass(options.loadingClass);
@@ -51,7 +51,10 @@
     $.fn.loadingOverlay.defaults = {
         loadingClass: 'loading',        // Class added to `target` while loading
         overlayClass: 'overlay',        // Class added to loading overlay (to be styled in CSS)
-        loadingText: 'loading...'       // Text within loading overlay
+        loadingText: 'loading...',      // Text within loading overlay
+        paddingTop: function (target) { // Function that returns desired padding-top for overlay text
+            return ((target.outerHeight() - parseInt(target.css('line-height'), 10)) / 2).toString() + 'px';
+        }
     };
 
 }(jQuery));
\ No newline at end of file
